@@ -7,20 +7,24 @@ if hasattr(asyncio, 'TaskGroup'):
     from . import persistent
     from .base import *        # noqa
     from .persistent import *  # noqa
-    __all__ = (
+    __all__ = [
         'MultiError',
         'TaskGroupError',
         *base.__all__,
         *persistent.__all__,
-    )
+    ]
 else:
     from . import base_compat
     from . import persistent_compat
     from .base_compat import *        # type: ignore  # noqa
     from .persistent_compat import *  # type: ignore  # noqa
-    __all__ = (  # type: ignore
+    __all__ = [  # type: ignore
         'MultiError',
         'TaskGroupError',
         *base_compat.__all__,
         *persistent_compat.__all__,
-    )
+    ]
+
+from .utils import as_completed_safe  # noqa
+
+__all__.append("as_completed_safe")
